#include <iostream>

#include <thrift/protocol/TBinaryProtocol.h>
#include <thrift/transport/TSocket.h>
#include <thrift/transport/TTransportUtils.h>

#include "AddrBook.h"

#define APPEND 1
#define FIND   2

using namespace std;
using namespace apache::thrift;
using namespace apache::thrift::protocol;
using namespace apache::thrift::transport;

int main(int argc, char * argv[]) {
	boost::shared_ptr<TTransport> socket(new TSocket("localhost", 9090));
	boost::shared_ptr<TTransport> transport(new TBufferedTransport(socket));
	boost::shared_ptr<TProtocol> protocol(new TBinaryProtocol(transport));
	AddrBookClient client(protocol);

	int mode;
	if (( argc < 3) || ( argc > 4)) {
		cout<<"usage: "<<argv[0]<<" -a name no | -f name"<<endl;
		exit(1);
	}
	if (strcmp(argv[1], "-a") == 0) mode = APPEND;
	else if (strcmp(argv[1], "-f") == 0) mode = FIND;
	else {
		cout<<"usage: "<<argv[0]<<" -a name no | -f name"<<endl;
		exit(1);
	}

	try {
		transport->open();
		
		if(mode == APPEND) {
			bool result = client.add(argv[2], argv[3]);
			cout<<"result: "<<result<<endl;
		} else {
			string no;
			client.get(no, argv[2]);
			cout<<"number of "<<argv[2]<< ": "<<no<<endl;
		}
	} catch(AddrNotFoundException & ex) {
		cout<<"number of "<<ex.msg<<" not found"<<endl;
	} catch (TException & tx) {
		cout << "ERROR: " << tx.what() << endl;
	}
	transport->close();

	return 0;
}
